@@ -16,7 +16,7 @@ import datetime
 import mimetypes
 import shutil
 from collections.abc import KeysView, MutableMapping
-from contextlib import ExitStack
+from contextlib import ExitStack, suppress
 from decimal import Decimal
 from io import BytesIO, RawIOBase
 from pathlib import Path
@@ -74,7 +74,7 @@ def _mudraw(buffer, fmt) -> bytes:
         tmp_in.flush()
 
         proc = run(
-            ['mudraw', '-F', fmt, '-o', '-', tmp_in.name],
+            ['mutool', 'draw', '-F', fmt, '-o', '-', tmp_in.name],
             capture_output=True,
             check=True,
         )
@@ -157,14 +157,20 @@ class Extend_Object:
 
 @augments(Pdf)
 class Extend_Pdf:
-    def _repr_mimebundle_(
-        self, include=None, exclude=None
-    ):  # pylint: disable=unused-argument
+    def _quick_save(self):
         bio = BytesIO()
         self.save(bio)
         bio.seek(0)
+        return bio
 
-        data = {'application/pdf': bio.read()}
+    def _repr_mimebundle_(
+        self, include=None, exclude=None
+    ):  # pylint: disable=unused-argument
+        pdf_data = self._quick_save().read()
+        data = {
+            'application/pdf': pdf_data,
+            'image/svg+xml': _mudraw(pdf_data, 'svg').decode('utf-8'),
+        }
         return data
 
     @property
@@ -430,19 +436,15 @@ class Extend_ObjectMapping:
 
 
 def check_is_box(obj) -> None:
-    try:
+    with suppress(AttributeError):
         if obj.is_rectangle:
             return
-    except AttributeError:
-        pass
-
     try:
         pdfobj = Array(obj)
         if pdfobj.is_rectangle:
             return
     except Exception as e:
         raise ValueError("object is not a rectangle") from e
-
     raise ValueError("object is not a rectangle")
 
 
@@ -661,7 +663,7 @@ class Extend_Page:
 
     def _repr_mimebundle_(self, include=None, exclude=None):
         data = {}
-        bundle = {'application/pdf', 'image/png'}
+        bundle = {'application/pdf', 'image/svg+xml'}
         if include:
             bundle = {k for k in bundle if k in include}
         if exclude:
@@ -669,11 +671,9 @@ class Extend_Page:
         pagedata = _single_page_pdf(self)
         if 'application/pdf' in bundle:
             data['application/pdf'] = pagedata
-        if 'image/png' in bundle:
-            try:
-                data['image/png'] = _mudraw(pagedata, 'png')
-            except (FileNotFoundError, RuntimeError):
-                pass
+        if 'image/svg+xml' in bundle:
+            with suppress(FileNotFoundError, RuntimeError):
+                data['image/svg+xml'] = _mudraw(pagedata, 'svg').decode('utf-8')
         return data
 
 
@@ -717,8 +717,6 @@ class Extend_Attachments(MutableMapping):
         yield from self._get_all_filespecs()
 
     def __repr__(self):
-        if len(self) == 0:
-            return "<pikepdf._core.Attachments no attached files>"
         return f"<pikepdf._core.Attachments: {list(self)}>"
 
 
